@@ -43,7 +43,15 @@ public:
 protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    /** @brief Given a TreeItem, check if the ID and Name (first and second)
+     * columns contain the filtered name as a substring.
+     * @return true if either ID or Name contains the filtered name as a
+     * substring, false otherwise
+     */
     bool filterName(const std::shared_ptr<TreeItem> &item) const;
+    /** @brief Returns a copy of the input string with any characters that are
+     * not letters, numbers, or spaces removed. */
+    static QString normalizeText(const QString &text);
     /** @brief Apply all filter and returns true if the object should be kept after filtering */
     virtual bool applyAll(std::shared_ptr<TreeItem> item) const;
 
