@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef ASSETTREEMODEL_H
-#define ASSETTREEMODEL_H
+#pragma once
 
 #include "abstractmodel/abstracttreemodel.hpp"
 
@@ -21,7 +20,7 @@ public:
     explicit AssetTreeModel(QObject *parent = nullptr);
 
     enum { IdRole = Qt::UserRole + 1, NameRole, FavoriteRole, TypeRole };
-    enum { NameCol = 0, IdCol = 1, TypeCol = 2, FavCol = 3, PreferredCol = 5};
+    enum { NameCol = 0, IdCol = 1, TypeCol = 2, FavCol = 3, PreferredCol = 5 };
 
     /** @brief Helper function to retrieve name */
     QString getName(const QModelIndex &index) const;
@@ -34,9 +33,7 @@ public:
     virtual void reloadAssetMenu(QMenu *effectsMenu, KActionCategory *effectActions) = 0;
     virtual void setFavorite(const QModelIndex &index, bool favorite, bool isEffect) = 0;
     virtual void deleteEffect(const QModelIndex &index) = 0;
-    virtual void editCustomAsset(const QString &newName,const QString &newDescription,const QModelIndex &index) = 0;
+    virtual void editCustomAsset(const QString &newName, const QString &newDescription, const QModelIndex &index) = 0;
 
 protected:
 };
-
-#endif
