@@ -21,7 +21,7 @@ RotoHelper::RotoHelper(Monitor *monitor, std::shared_ptr<AssetParameterModel> mo
 void RotoHelper::slotUpdateFromMonitorData(const QVariantList &v)
 {
     const QVariant res = RotoHelper::getSpline(QVariant(v), pCore->getCurrentFrameSize());
-    emit updateKeyframeData(m_indexes.first(), res);
+    Q_EMIT updateKeyframeData(m_indexes.first(), res);
 }
 
 QVariant RotoHelper::getSpline(const QVariant &value, const QSize frame)
@@ -33,7 +33,7 @@ QVariant RotoHelper::getSpline(const QVariant &value, const QSize frame)
         bPoints << b;
     }
     QList<QVariant> vlist;
-    foreach (const BPoint &point, bPoints) {
+    for (const BPoint &point : bPoints) {
         QList<QVariant> pl;
         for (int i = 0; i < 3; ++i) {
             pl << QVariant(QList<QVariant>() << QVariant(point[i].x() / frame.width()) << QVariant(point[i].y() / frame.height()));
@@ -72,7 +72,7 @@ QList<BPoint> RotoHelper::getPoints(const QVariant &value, const QSize frame)
         data.removeFirst();
     }
 
-    foreach (const QVariant &bpoint, data) {
+    for (const QVariant &bpoint : data) {
         QList<QVariant> l = bpoint.toList();
         BPoint p;
         for (int i = 0; i < 3; ++i) {
