@@ -33,7 +33,7 @@ UrlListParamWidget::UrlListParamWidget(std::shared_ptr<AssetParameterModel> mode
     // setup download
     if (!configFile.isEmpty()) {
         m_knsbutton->setConfigFile(configFile);
-        connect(m_knsbutton, &KNSWidgets::Button::dialogFinished, this, [&](const QList<KNSCore::Entry> &changedEntries) {
+        connect(m_knsbutton, &KNSWidgets::Button::dialogFinished, this, [this, configFile](const QList<KNSCore::Entry> &changedEntries) {
             if (changedEntries.count() > 0) {
                 if (configFile.contains(QStringLiteral("kdenlive_wipes.knsrc"))) {
                     MltConnection::refreshLumas();
@@ -147,12 +147,16 @@ void UrlListParamWidget::slotRefresh()
     if (!currentValue.isEmpty()) {
         QString path = QUrl(currentValue).adjusted(QUrl::RemoveFilename).toString();
         QDir dir(path);
-        QStringList entrys = dir.entryList(m_fileExt, QDir::Files);
-        for (const auto &filename : qAsConst(entrys)) {
-            values.append(dir.filePath(filename));
+        if (dir.exists()) {
+            QStringList entrys = dir.entryList(m_fileExt, QDir::Files);
+            for (const auto &filename : qAsConst(entrys)) {
+                values.append(dir.filePath(filename));
+            }
+            // make sure the current value is added. If it is a duplicate we remove it later
+            if (QFileInfo::exists(currentValue)) {
+                values << currentValue;
+            }
         }
-        // make sure the current value is added. If it is a duplicate we remove it later
-        values << currentValue;
     }
 
     values.removeDuplicates();
