@@ -27,6 +27,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "xml/xml.hpp"
 
 #include <KLocalizedString>
+
 #include <QIcon>
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -237,7 +238,7 @@ bool ProjectItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action
     }
 
     if (data->hasUrls()) {
-        Q_EMIT itemDropped(data->urls(), parent);
+        Q_EMIT urlsDropped(data->urls(), parent);
         return true;
     }
 
@@ -403,8 +404,22 @@ QMimeData *ProjectItemModel::mimeData(const QModelIndexList &indices) const
             duration += (std::static_pointer_cast<ProjectClip>(item))->frameDuration();
         } else if (type == AbstractProjectItem::SubClipItem) {
             QPoint p = item->zone();
-            list << std::static_pointer_cast<ProjectSubClip>(item)->getMasterClip()->clipId() + QLatin1Char('/') + QString::number(p.x()) + QLatin1Char('/') +
-                        QString::number(p.y());
+            std::shared_ptr<ProjectClip> master = std::static_pointer_cast<ProjectSubClip>(item)->getMasterClip();
+            QString dragId = master->clipId();
+            ClipType::ProducerType cType = master->clipType();
+            if ((cType == ClipType::AV || cType == ClipType::Playlist || cType == ClipType::Timeline)) {
+                switch (m_dragType) {
+                case PlaylistState::AudioOnly:
+                    dragId.prepend(QLatin1Char('A'));
+                    break;
+                case PlaylistState::VideoOnly:
+                    dragId.prepend(QLatin1Char('V'));
+                    break;
+                default:
+                    break;
+                }
+            }
+            list << dragId + QLatin1Char('/') + QString::number(p.x()) + QLatin1Char('/') + QString::number(p.y());
         } else if (type == AbstractProjectItem::FolderItem) {
             list << "#" + item->clipId();
         }
@@ -464,14 +479,9 @@ void ProjectItemModel::onItemUpdated(const QString &binId, int role)
 std::shared_ptr<ProjectClip> ProjectItemModel::getClipByBinID(const QString &binId)
 {
     READ_LOCK();
-    if (binId.contains(QLatin1Char('_'))) {
-        return getClipByBinID(binId.section(QLatin1Char('_'), 0, 0));
-    }
-    for (const auto &clip : m_allItems) {
-        auto c = std::static_pointer_cast<AbstractProjectItem>(clip.second.lock());
-        if (c->itemType() == AbstractProjectItem::ClipItem && c->clipId() == binId) {
-            return std::static_pointer_cast<ProjectClip>(c);
-        }
+    auto search = m_allClipItems.find(binId.toInt());
+    if (search != m_allClipItems.end()) {
+        return search->second;
     }
     return nullptr;
 }
@@ -479,11 +489,9 @@ std::shared_ptr<ProjectClip> ProjectItemModel::getClipByBinID(const QString &bin
 const QVector<uint8_t> ProjectItemModel::getAudioLevelsByBinID(const QString &binId, int stream)
 {
     READ_LOCK();
-    for (const auto &clip : m_allItems) {
-        auto c = std::static_pointer_cast<AbstractProjectItem>(clip.second.lock());
-        if (c->itemType() == AbstractProjectItem::ClipItem && c->clipId() == binId) {
-            return std::static_pointer_cast<ProjectClip>(c)->audioFrameCache(stream);
-        }
+    auto search = m_allClipItems.find(binId.toInt());
+    if (search != m_allClipItems.end()) {
+        return search->second->audioFrameCache(stream);
     }
     return QVector<uint8_t>();
 }
@@ -491,14 +499,9 @@ const QVector<uint8_t> ProjectItemModel::getAudioLevelsByBinID(const QString &bi
 double ProjectItemModel::getAudioMaxLevel(const QString &binId, int stream)
 {
     READ_LOCK();
-    for (const auto &item : m_allItems) {
-        auto i = std::static_pointer_cast<AbstractProjectItem>(item.second.lock());
-        if (i->itemType() == AbstractProjectItem::ClipItem && i->clipId() == binId) {
-            auto clip = std::static_pointer_cast<ProjectClip>(i);
-            if (clip) {
-                return clip->getAudioMax(stream);
-            }
-        }
+    auto search = m_allClipItems.find(binId.toInt());
+    if (search != m_allClipItems.end()) {
+        return search->second->getAudioMax(stream);
     }
     return 0;
 }
@@ -696,6 +699,9 @@ bool ProjectItemModel::requestBinClipDeletion(const std::shared_ptr<AbstractProj
     if (!clip) return false;
     int parentId = -1;
     QString binId;
+    if (clip->clipId().toInt() == m_sequenceFolderId) {
+        setSequencesFolder(-1);
+    }
     if (auto ptr = clip->parent()) {
         parentId = ptr->getId();
         binId = ptr->clipId();
@@ -736,8 +742,10 @@ void ProjectItemModel::registerItem(const std::shared_ptr<TreeItem> &item)
     auto clip = std::static_pointer_cast<AbstractProjectItem>(item);
     m_binPlaylist->manageBinItemInsertion(clip);
     AbstractTreeModel::registerItem(item);
+    m_allIds.append(clip->clipId().toInt());
     if (clip->itemType() == AbstractProjectItem::ClipItem) {
         auto clipItem = std::static_pointer_cast<ProjectClip>(clip);
+        m_allClipItems[clip->clipId().toInt()] = clipItem;
         updateWatcher(clipItem);
         if (clipItem->clipType() == ClipType::Timeline && clipItem->statusReady()) {
             const QString uuid = clipItem->getSequenceUuid().toString();
@@ -751,6 +759,8 @@ void ProjectItemModel::deregisterItem(int id, TreeItem *item)
 {
     QWriteLocker locker(&m_lock);
     auto clip = static_cast<AbstractProjectItem *>(item);
+    m_allIds.removeAll(clip->clipId().toInt());
+    m_allClipItems.erase(clip->clipId().toInt());
     m_binPlaylist->manageBinItemDeletion(clip);
     // TODO : here, we should suspend jobs belonging to the item we delete. They can be restarted if the item is reinserted by undo
     AbstractTreeModel::deregisterItem(id, item);
@@ -771,6 +781,12 @@ bool ProjectItemModel::hasSequenceId(const QUuid &uuid) const
     return m_binPlaylist->hasSequenceId(uuid);
 }
 
+std::shared_ptr<ProjectClip> ProjectItemModel::getSequenceClip(const QUuid &uuid)
+{
+    const QString binId = getSequenceId(uuid);
+    return getClipByBinID(binId);
+}
+
 QMap<QUuid, QString> ProjectItemModel::getAllSequenceClips() const
 {
     return m_binPlaylist->getAllSequenceClips();
@@ -841,7 +857,6 @@ bool ProjectItemModel::requestAddFolder(QString &id, const QString &name, const
 bool ProjectItemModel::requestAddBinClip(QString &id, const QDomElement &description, const QString &parentId, Fun &undo, Fun &redo,
                                          const std::function<void(const QString &)> &readyCallBack)
 {
-    QWriteLocker locker(&m_lock);
     if (id.isEmpty()) {
         id = Xml::getXmlProperty(description, QStringLiteral("kdenlive:id"), QStringLiteral("-1"));
         if (id == QStringLiteral("-1") || !isIdFree(id)) {
@@ -849,8 +864,10 @@ bool ProjectItemModel::requestAddBinClip(QString &id, const QDomElement &descrip
         }
     }
     Q_ASSERT(isIdFree(id));
+    QWriteLocker locker(&m_lock);
     std::shared_ptr<ProjectClip> new_clip =
         ProjectClip::construct(id, description, m_blankThumb, std::static_pointer_cast<ProjectItemModel>(shared_from_this()));
+    locker.unlock();
     bool res = addItem(new_clip, parentId, undo, redo);
     if (res) {
         ClipLoadTask::start(ObjectId(ObjectType::BinClip, id.toInt(), QUuid()), description, false, -1, -1, this, false, std::bind(readyCallBack, id));
@@ -1155,21 +1172,17 @@ bool ProjectItemModel::isIdFree(const QString &id) const
     if (id.isEmpty()) {
         return false;
     }
-    for (const auto &clip : m_allItems) {
-        auto c = std::static_pointer_cast<AbstractProjectItem>(clip.second.lock());
-        if (c->clipId() == id) {
-            return false;
-        }
-    }
-    return true;
+    return !m_allIds.contains(id.toInt());
 }
 
 QList<QUuid> ProjectItemModel::loadBinPlaylist(Mlt::Service *documentTractor, std::unordered_map<QString, QString> &binIdCorresp, QStringList &expandedFolders,
-                                               int &zoomLevel, QProgressDialog *progressDialog)
+                                               const QUuid &activeUuid, int &zoomLevel, QProgressDialog *progressDialog)
 {
     QWriteLocker locker(&m_lock);
     clean();
     QList<QUuid> brokenSequences;
+    QList<QUuid> foundSequences;
+    QList<int> foundIds;
     Mlt::Properties retainList(mlt_properties(documentTractor->get_data("xml_retain")));
     if (retainList.is_valid()) {
         Mlt::Playlist playlist(mlt_playlist(retainList.get_data(BinPlaylist::binPlaylistId.toUtf8().constData())));
@@ -1183,17 +1196,14 @@ QList<QUuid> ProjectItemModel::loadBinPlaylist(Mlt::Service *documentTractor, st
             Mlt::Properties playlistProps(playlist.get_properties());
             expandedFolders = QString(playlistProps.get("kdenlive:expandedFolders")).split(QLatin1Char(';'));
             folderProperties.pass_values(playlistProps, "kdenlive:folder.");
+            loadFolders(folderProperties, binIdCorresp);
+            m_sequenceFolderId = -1;
             if (playlistProps.property_exists("kdenlive:sequenceFolder")) {
                 int sequenceFolder = playlistProps.get_int("kdenlive:sequenceFolder");
-                if (binIdCorresp.count(QString::number(sequenceFolder)) > 0) {
-                    m_sequenceFolderId = binIdCorresp.at(QString::number(sequenceFolder)).toInt();
-                } else {
-                    m_sequenceFolderId = sequenceFolder;
+                if (sequenceFolder > -1 && binIdCorresp.count(QString::number(sequenceFolder)) > 0) {
+                    setSequencesFolder(binIdCorresp.at(QString::number(sequenceFolder)).toInt());
                 }
-            } else {
-                m_sequenceFolderId = -1;
             }
-            loadFolders(folderProperties, binIdCorresp);
 
             // Load Zoom level
             if (playlistProps.property_exists("kdenlive:binZoom")) {
@@ -1225,8 +1235,13 @@ QList<QUuid> ProjectItemModel::loadBinPlaylist(Mlt::Service *documentTractor, st
                 std::shared_ptr<Mlt::Producer> producer;
                 if (prod->parent().property_exists("kdenlive:uuid")) {
                     const QUuid uuid(prod->parent().get("kdenlive:uuid"));
+                    if (foundSequences.contains(uuid)) {
+                        qDebug() << "FOUND DUPLICATED SEQUENCE: " << uuid.toString();
+                        Q_ASSERT(false);
+                    }
                     if (prod->parent().type() == mlt_service_tractor_type) {
                         // Load sequence properties
+                        foundSequences << uuid;
                         Mlt::Properties sequenceProps;
                         sequenceProps.pass_values(prod->parent(), "kdenlive:sequenceproperties.");
                         pCore->currentDoc()->loadSequenceProperties(uuid, sequenceProps);
@@ -1243,6 +1258,7 @@ QList<QUuid> ProjectItemModel::loadBinPlaylist(Mlt::Service *documentTractor, st
                         trac->set("kdenlive:duration", prod->parent().get("kdenlive:duration"));
                         trac->set("kdenlive:producer_type", ClipType::Timeline);
                         trac->set("kdenlive:maxduration", prod->parent().get_int("kdenlive:maxduration"));
+                        trac->set("_kdenlive_processed", 1);
                         std::shared_ptr<Mlt::Producer> prod2(trac->cut());
 
                         prod2->set("kdenlive:id", id);
@@ -1255,6 +1271,13 @@ QList<QUuid> ProjectItemModel::loadBinPlaylist(Mlt::Service *documentTractor, st
                         prod2->set("kdenlive:duration", prod->parent().get("kdenlive:duration"));
                         prod2->set("kdenlive:producer_type", ClipType::Timeline);
                         prod2->set("kdenlive:maxduration", prod->parent().get_int("kdenlive:maxduration"));
+                        prod2->set("_kdenlive_processed", 1);
+                        if (foundIds.contains(id)) {
+                            qWarning() << "ERROR, several Sequence Clips using the same id: " << id << ", UUID: " << uuid.toString()
+                                       << "\n____________________";
+                            brokenSequences << uuid;
+                        }
+                        foundIds << id;
                         binProducers.insert(id, prod2);
                         continue;
                     } else {
@@ -1263,21 +1286,43 @@ QList<QUuid> ProjectItemModel::loadBinPlaylist(Mlt::Service *documentTractor, st
                             // Buggy internal xml producer, drop
                             qDebug() << "/// AARGH INCORRECT SEQUENCE CLIP IN PROJECT BIN... TRY TO RECOVER";
                             brokenSequences.append(QUuid(uuid));
-                            continue;
                         }
                     }
-                } else {
-                    producer.reset(new Mlt::Producer(prod->parent()));
+                    continue;
                 }
-                int id = producer->parent().get_int("kdenlive:id");
+                producer.reset(new Mlt::Producer(prod->parent()));
+                int id = producer->get_int("kdenlive:id");
                 if (!id) {
                     qDebug() << "WARNING THIS SHOULD NOT HAPPEN, BIN CLIP WITHOUT ID: " << producer->parent().get("resource")
                              << ", ID: " << producer->parent().get("id") << "\n\nFZFZFZFZFZFZFZFZFZFZFZFZFZ";
                     // Using a temporary negative reference so we don't mess with yet unloaded clips
                     id = -getFreeClipId();
+                } else {
+                    if (foundIds.contains(id)) {
+                        qWarning() << "ERROR, several Bin Clips using the same id: " << id << "\n____________________";
+                        Q_ASSERT(false);
+                    }
+                    foundIds << id;
                 }
                 binProducers.insert(id, producer);
             }
+            // Ensure active playlist is in the project bin
+            if (!foundSequences.contains(activeUuid)) {
+                // Project corruption, try to restore sequence from the ProjectTractor
+                Mlt::Tractor tractor(*documentTractor);
+                std::shared_ptr<Mlt::Producer> tk(tractor.track(0));
+                std::shared_ptr<Mlt::Producer> producer(new Mlt::Producer(tk->parent()));
+                const QUuid uuid(producer->get("kdenlive:uuid"));
+                if (!uuid.isNull() && uuid == activeUuid) {
+                    // TODO: Show user info about the recovered corruption
+                    qWarning() << "Recovering corrupted sequence: " << uuid.toString();
+                    int id = producer->get_int("kdenlive:id");
+                    binProducers.insert(id, std::move(producer));
+                    foundSequences << activeUuid;
+                } else {
+                    brokenSequences << activeUuid;
+                }
+            }
             // Do the real insertion
             QList<int> binIds = binProducers.keys();
 
@@ -1481,12 +1526,12 @@ void ProjectItemModel::setExtraTimelineSaved(const QString &uuid)
     }
 }
 
-void ProjectItemModel::removeReferencedClips(const QUuid &uuid)
+void ProjectItemModel::removeReferencedClips(const QUuid &uuid, bool onDeletion)
 {
     QList<std::shared_ptr<ProjectClip>> clipList = getRootFolder()->childClips();
     for (const std::shared_ptr<ProjectClip> &clip : qAsConst(clipList)) {
         if (clip->refCount() > 0) {
-            clip->purgeReferences(uuid);
+            clip->purgeReferences(uuid, onDeletion);
         }
     }
 }
@@ -1624,3 +1669,13 @@ void ProjectItemModel::setSequencesFolder(int id)
     m_sequenceFolderId = id;
     saveProperty(QStringLiteral("kdenlive:sequenceFolder"), QString::number(id));
 }
+
+void ProjectItemModel::checkSequenceIntegrity(const QString activeSequenceId)
+{
+    QStringList sequencesIds = pCore->currentDoc()->getTimelinesIds();
+    Q_ASSERT(sequencesIds.contains(activeSequenceId));
+    QStringList allMltIds = m_binPlaylist->getAllMltIds();
+    for (auto &i : sequencesIds) {
+        Q_ASSERT(allMltIds.contains(i));
+    }
+}
