@@ -107,7 +107,7 @@ public:
      *  @return A list of invalid sequence clips found in Project Bin (can be caused by 23.04.0 bug)
      */
     QList<QUuid> loadBinPlaylist(Mlt::Service *documentTractor, std::unordered_map<QString, QString> &binIdCorresp, QStringList &expandedFolders,
-                                 int &zoomLevel, QProgressDialog *progressDialog = nullptr);
+                                 const QUuid &activeUuid, int &zoomLevel, QProgressDialog *progressDialog = nullptr);
     void loadTractorPlaylist(Mlt::Tractor documentTractor, std::unordered_map<QString, QString> &binIdCorresp);
 
     /** @brief Save document properties in MLT's bin playlist */
@@ -226,6 +226,8 @@ public:
     const QString getSequenceId(const QUuid &uuid);
     /** @brief Check if we already have a sequence with this uuid */
     bool hasSequenceId(const QUuid &uuid) const;
+    /** @brief Return a project sequence clip from its uuid */
+    std::shared_ptr<ProjectClip> getSequenceClip(const QUuid &uuid);
     /** @brief Returns uuid / bin id of all sequence clips in the project */
     QMap<QUuid, QString> getAllSequenceClips() const;
     /** @brief Return the main project tractor (container of all playlists) */
@@ -241,7 +243,9 @@ public:
     int defaultSequencesFolder() const;
     void setSequencesFolder(int id);
     /** @brief Remove clip references for a timeline. */
-    void removeReferencedClips(const QUuid &uuid);
+    void removeReferencedClips(const QUuid &uuid, bool onDeletion);
+    /** @brief Check that all sequences are correctly stored in the model */
+    void checkSequenceIntegrity(const QString activeSequenceId);
 
 protected:
     bool closing;
@@ -284,6 +288,8 @@ private:
     std::unique_ptr<FileWatcher> m_fileWatcher;
     std::unordered_map<QString, std::shared_ptr<Mlt::Tractor>> m_extraPlaylists;
     std::shared_ptr<Mlt::Tractor> m_projectTractor;
+    std::map<int, std::shared_ptr<ProjectClip>> m_allClipItems;
+    QList<int> m_allIds;
 
     int m_nextId;
     QIcon m_blankThumb;
@@ -301,8 +307,8 @@ Q_SIGNALS:
     void requestAudioThumbs(const QString &id, long duration);
     // TODO
     void markersNeedUpdate(const QString &id, const QList<int> &);
-    void itemDropped(const QStringList &, const QModelIndex &);
-    void itemDropped(const QList<QUrl> &, const QModelIndex &);
+    void itemDropped(const QStringList, const QModelIndex);
+    void urlsDropped(const QList<QUrl>, const QModelIndex);
     void effectDropped(const QStringList &, const QModelIndex &);
     void addTag(const QString &, const QModelIndex &);
     void addClipCut(const QString &, int, int);
