@@ -152,10 +152,9 @@ void Core::initGUI(bool inSandbox, const QString &MltPath, const QUrl &Url, cons
     connect(bin, &Bin::requestShowClipProperties, bin, &Bin::showClipProperties);
     connect(m_projectItemModel.get(), &ProjectItemModel::refreshPanel, m_mainWindow->activeBin(), &Bin::refreshPanel);
     connect(m_projectItemModel.get(), &ProjectItemModel::refreshClip, m_mainWindow->activeBin(), &Bin::refreshClip);
-    connect(m_projectItemModel.get(), static_cast<void (ProjectItemModel::*)(const QStringList &, const QModelIndex &)>(&ProjectItemModel::itemDropped),
-            m_mainWindow->activeBin(), static_cast<void (Bin::*)(const QStringList &, const QModelIndex &)>(&Bin::slotItemDropped));
-    connect(m_projectItemModel.get(), static_cast<void (ProjectItemModel::*)(const QList<QUrl> &, const QModelIndex &)>(&ProjectItemModel::itemDropped),
-            m_mainWindow->activeBin(), static_cast<const QString (Bin::*)(const QList<QUrl> &, const QModelIndex &)>(&Bin::slotItemDropped));
+    connect(m_projectItemModel.get(), &ProjectItemModel::itemDropped, m_mainWindow->activeBin(), &Bin::slotItemDropped, Qt::QueuedConnection);
+    connect(m_projectItemModel.get(), &ProjectItemModel::urlsDropped, m_mainWindow->activeBin(), &Bin::slotUrlsDropped, Qt::QueuedConnection);
+
     connect(m_projectItemModel.get(), &ProjectItemModel::effectDropped, m_mainWindow->activeBin(), &Bin::slotEffectDropped);
     connect(m_projectItemModel.get(), &ProjectItemModel::addTag, m_mainWindow->activeBin(), &Bin::slotTagDropped);
     connect(m_projectItemModel.get(), &QAbstractItemModel::dataChanged, m_mainWindow->activeBin(), &Bin::slotItemEdited);
@@ -687,6 +686,8 @@ int Core::getItemPosition(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipPosition(id.itemId);
+        } else {
+            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::TimelineComposition:
@@ -765,6 +766,8 @@ PlaylistState::ClipState Core::getItemState(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipState(id.itemId);
+        } else {
+            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::TimelineComposition:
@@ -789,6 +792,8 @@ int Core::getItemDuration(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipPlaytime(id.itemId);
+        } else {
+            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::TimelineComposition:
@@ -821,6 +826,8 @@ QSize Core::getItemFrameSize(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (currentDoc()->getTimeline(id.uuid)->isClip(id.itemId)) {
             return currentDoc()->getTimeline(id.uuid)->getClipFrameSize(id.itemId);
+        } else {
+            qWarning() << "querying non clip properties";
         }
         break;
     case ObjectType::BinClip:
