@@ -13,6 +13,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "kdenlive_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QButtonGroup>
 #include <QFontDatabase>
 #include <QUuid>
 
@@ -40,18 +41,44 @@ ClipJobManager::ClipJobManager(AbstractTask::JOBTYPE type, QWidget *parent)
     connect(button_add, &QToolButton::clicked, this, &ClipJobManager::addJob);
     connect(button_delete, &QToolButton::clicked, this, &ClipJobManager::deleteJob);
 
-    QIcon icon = QIcon::fromTheme(QStringLiteral("help-about"));
-    int size = style()->pixelMetric(QStyle::PM_SmallIconSize);
-    QPixmap pix = icon.pixmap(size, size);
-    help_arguments->setPixmap(pix);
-    help_arguments->setToolTip(i18n("Arguments for the command line script"));
-    help_arguments->setWhatsThis(xi18nc("@info:whatsthis", "<b>&#x25;1</b> will be replaced be the path of the source clip."));
-    help_output->setPixmap(pix);
-    help_output->setToolTip(i18n("File extension for the output file"));
-    help_output->setWhatsThis(xi18nc("@info:whatsthis", "File extension for the output file. Empty will keep the same extension as source file."));
+    job_params->setToolTip(i18n("Arguments for the command line script"));
+    job_params->setWhatsThis(
+        xi18nc("@info:whatsthis",
+               "<b>{&#x25;1}</b> will be replaced by the first parameter, <b>{&#x25;2}</b> by the second, , <b>{&#x25;3}</b> by the output file path."));
+    destination_pattern->setToolTip(i18n("File extension for the output file"));
+    destination_pattern->setWhatsThis(
+        xi18nc("@info:whatsthis",
+               "The output file name will be the same as the source bin clip filename, with the modified extension. It will be appended at the end of the "
+               "arguments or inserted in place of <b>{&#x25;3}</b> if found. If output filename already exists, a -0001 pattern will be appended."));
+
+    param1_isfile->setToolTip(i18n("The first parameter that will be injected in the script arguments"));
+    param1_isfile->setWhatsThis(xi18nc("@info:whatsthis",
+                                       "<b>Source Clip Path</b> will put the selected Bin Clip path<br/><b>Request File Path</b> will ask for a file path on "
+                                       "execution<br/><b>Request Option in List</b> will ask for a choice in the list below on execution."));
+
+    param1_list->setToolTip(i18n("A newline separated list of possible values that will be offered on execution"));
+    param1_list->setWhatsThis(
+        xi18nc("@info:whatsthis",
+               "When the parameter is set to <b>Request Option in List</b> the user will be asked to choose a value in this list when the job is started."));
+
+    param2_isfile->setToolTip(i18n("The second parameter that will be injected in the script arguments"));
+    param2_isfile->setWhatsThis(xi18nc("@info:whatsthis",
+                                       "<b>Source Clip Path</b> will put the selected Bin Clip path<br/><b>Request File Path</b> will ask for a file path on "
+                                       "execution<br/><b>Request Option in List</b> will ask for a choice in the list below on execution."));
+
+    param2_list->setToolTip(i18n("A newline separated list of possible values that will be offered on execution"));
+    param2_list->setWhatsThis(
+        xi18nc("@info:whatsthis",
+               "When the parameter is set to <b>Request Option in List</b> the user will be asked to choose a value in this list when the job is started."));
 
     connect(job_list, &QListWidget::itemChanged, this, &ClipJobManager::updateName);
 
+    QButtonGroup *bg = new QButtonGroup(this);
+    bg->setExclusive(false);
+    bg->addButton(enable_video);
+    bg->addButton(enable_audio);
+    bg->addButton(enable_image);
+
     // Mark preset as dirty if anything changes
     connect(url_binary, &KUrlRequester::textChanged, this, &ClipJobManager::setDirty);
     connect(job_params, &QPlainTextEdit::textChanged, this, &ClipJobManager::setDirty);
@@ -59,6 +86,16 @@ ClipJobManager::ClipJobManager(AbstractTask::JOBTYPE type, QWidget *parent)
     connect(radio_replace, &QRadioButton::toggled, this, &ClipJobManager::setDirty);
     connect(combo_folder, &QComboBox::currentIndexChanged, this, &ClipJobManager::setDirty);
     connect(folder_name, &QLineEdit::textChanged, this, &ClipJobManager::setDirty);
+    connect(param1_list, &QPlainTextEdit::textChanged, this, &ClipJobManager::setDirty);
+    connect(param2_list, &QPlainTextEdit::textChanged, this, &ClipJobManager::setDirty);
+    connect(taskDescription, &QPlainTextEdit::textChanged, this, &ClipJobManager::setDirty);
+    connect(param1_islist, &QAbstractButton::toggled, this, &ClipJobManager::setDirty);
+    connect(param2_islist, &QAbstractButton::toggled, this, &ClipJobManager::setDirty);
+    connect(param1_name, &QLineEdit::textChanged, this, &ClipJobManager::setDirty);
+    connect(param2_name, &QLineEdit::textChanged, this, &ClipJobManager::setDirty);
+    connect(bg, &QButtonGroup::idToggled, this, &ClipJobManager::setDirty);
+    info_message->setVisible(false);
+
     connect(buttonBox->button(QDialogButtonBox::Close), &QPushButton::clicked, this, &ClipJobManager::validate);
 }
 
@@ -115,6 +152,22 @@ void ClipJobManager::loadJobs()
     m_output = groupOutput.entryMap();
     KConfigGroup groupBinary(&conf, "Binary");
     m_binaries = groupBinary.entryMap();
+    KConfigGroup groupEnabled(&conf, "EnabledTypes");
+    m_enableType = groupEnabled.entryMap();
+    KConfigGroup param1Type(&conf, "Param1Type");
+    m_param1Type = param1Type.entryMap();
+    KConfigGroup param1List(&conf, "Param1List");
+    m_param1List = param1List.entryMap();
+    KConfigGroup param2Type(&conf, "Param2Type");
+    m_param2Type = param2Type.entryMap();
+    KConfigGroup param2List(&conf, "Param2List");
+    m_param2List = param2List.entryMap();
+    KConfigGroup param1Name(&conf, "Param1Name");
+    m_param1Name = param1Name.entryMap();
+    KConfigGroup param2Name(&conf, "Param2Name");
+    m_param2Name = param2Name.entryMap();
+    KConfigGroup descName(&conf, "Description");
+    m_description = descName.entryMap();
 }
 
 void ClipJobManager::displayJob(int row)
@@ -134,7 +187,7 @@ void ClipJobManager::displayJob(int row)
     if (customJob && !m_ids.contains(jobId)) {
         // This is a new job, set some default values
         url_binary->setUrl(QUrl::fromLocalFile(KdenliveSettings::ffmpegpath()));
-        job_params->setPlainText(QStringLiteral("-i %1 -codec:a copy -codec:v copy"));
+        job_params->setPlainText(QStringLiteral("-i {source} -codec:a copy -codec:v copy {output}"));
     } else {
         url_binary->setText(m_binaries.value(jobId));
         job_params->setPlainText(m_params.value(jobId));
@@ -158,6 +211,28 @@ void ClipJobManager::displayJob(int row)
     } else {
         folder_box->setEnabled(false);
     }
+    enable_video->setChecked(m_enableType.value(jobId).contains(QLatin1String("v")));
+    enable_audio->setChecked(m_enableType.value(jobId).contains(QLatin1String("a")));
+    enable_image->setChecked(m_enableType.value(jobId).contains(QLatin1String("i")));
+
+    if (m_param1Type.value(jobId) == QLatin1String("list")) {
+        param1_islist->setChecked(true);
+    } else {
+        param1_isfile->setChecked(true);
+    }
+    if (m_param2Type.value(jobId) == QLatin1String("list")) {
+        param2_islist->setChecked(true);
+    } else {
+        param2_isfile->setChecked(true);
+    }
+    param1_name->setText(m_param1Name.value(jobId));
+    param2_name->setText(m_param2Name.value(jobId));
+    taskDescription->setPlainText(m_description.value(jobId));
+
+    QStringList option1 = m_param1List.value(jobId).split(QLatin1String("  "));
+    param1_list->setPlainText(option1.join(QLatin1Char('\n')));
+    QStringList option2 = m_param2List.value(jobId).split(QLatin1String("  "));
+    param2_list->setPlainText(option2.join(QLatin1Char('\n')));
 }
 
 QMap<QString, QString> ClipJobManager::getClipJobNames()
@@ -165,15 +240,26 @@ QMap<QString, QString> ClipJobManager::getClipJobNames()
     KConfig conf(QStringLiteral("clipjobsettings.rc"), KConfig::CascadeConfig, QStandardPaths::AppDataLocation);
     KConfigGroup group(&conf, "Ids");
     QMap<QString, QString> ids = group.entryMap();
+    KConfigGroup group2(&conf, "EnabledTypes");
+    QMap<QString, QString> id2s = group2.entryMap();
+    // Append supported type after job key
+    QMapIterator<QString, QString> i(ids);
+    QMap<QString, QString> newIds;
+    while (i.hasNext()) {
+        i.next();
+        if (!i.value().isEmpty()) {
+            newIds.insert(QString("%1;%2").arg(i.key(), id2s.value(i.key())), i.value());
+        }
+    }
     // Add the 3 internal jobs
     if (EffectsRepository::get()->exists(QLatin1String("vidstab"))) {
-        ids.insert(QStringLiteral("stabilize"), i18n("Stabilize"));
+        newIds.insert(QStringLiteral("stabilize;v"), i18n("Stabilize"));
     }
-    ids.insert(QStringLiteral("scenesplit"), i18n("Automatic Scene Split…"));
+    newIds.insert(QStringLiteral("scenesplit;v"), i18n("Automatic Scene Split…"));
     if (KdenliveSettings::producerslist().contains(QLatin1String("timewarp"))) {
-        ids.insert(QStringLiteral("timewarp"), i18n("Duplicate Clip with Speed Change…"));
+        newIds.insert(QStringLiteral("timewarp;av"), i18n("Duplicate Clip with Speed Change…"));
     }
-    return ids;
+    return newIds;
 }
 
 std::pair<ClipJobManager::JobCompletionAction, QString> ClipJobManager::getJobAction(const QString &jobId)
@@ -194,18 +280,32 @@ std::pair<ClipJobManager::JobCompletionAction, QString> ClipJobManager::getJobAc
     return {JobCompletionAction::NoAction, nameGroup.readEntry(jobId, QString())};
 }
 
-QStringList ClipJobManager::getJobParameters(const QString &jobId)
+QMap<QString, QString> ClipJobManager::getJobParameters(const QString &jobId)
 {
-    QStringList result;
+    QMap<QString, QString> result;
     KConfig conf(QStringLiteral("clipjobsettings.rc"), KConfig::CascadeConfig, QStandardPaths::AppDataLocation);
     KConfigGroup idGroup(&conf, "Ids");
-    result << idGroup.readEntry(jobId, i18n("Job description"));
+    result.insert(QLatin1String("description"), idGroup.readEntry(jobId, i18n("Job description")));
     KConfigGroup group(&conf, "Binary");
-    result << group.readEntry(jobId, QString());
+    result.insert(QLatin1String("binary"), group.readEntry(jobId, QString()));
     KConfigGroup paramGroup(&conf, "Parameters");
-    result << paramGroup.readEntry(jobId, QString());
+    result.insert(QLatin1String("parameters"), paramGroup.readEntry(jobId, QString()));
     KConfigGroup outGroup(&conf, "Output");
-    result << outGroup.readEntry(jobId, QString());
+    result.insert(QLatin1String("output"), outGroup.readEntry(jobId, QString()));
+    KConfigGroup p1Group(&conf, "Param1Type");
+    result.insert(QLatin1String("param1type"), p1Group.readEntry(jobId, QString()));
+    KConfigGroup p2Group(&conf, "Param2Type");
+    result.insert(QLatin1String("param2type"), p2Group.readEntry(jobId, QString()));
+    KConfigGroup p1List(&conf, "Param1List");
+    result.insert(QLatin1String("param1list"), p1List.readEntry(jobId, QString()));
+    KConfigGroup p2List(&conf, "Param2List");
+    result.insert(QLatin1String("param2list"), p2List.readEntry(jobId, QString()));
+    KConfigGroup p1Name(&conf, "Param1Name");
+    result.insert(QLatin1String("param1name"), p1Name.readEntry(jobId, QString()));
+    KConfigGroup p2Name(&conf, "Param2Name");
+    result.insert(QLatin1String("param2name"), p2Name.readEntry(jobId, QString()));
+    KConfigGroup descName(&conf, "Description");
+    result.insert(QLatin1String("details"), descName.readEntry(jobId, QString()));
     return result;
 }
 
@@ -222,6 +322,27 @@ void ClipJobManager::saveCurrentPreset()
     m_binaries.insert(m_dirty, url_binary->text().simplified());
     m_params.insert(m_dirty, job_params->toPlainText().simplified());
     m_output.insert(m_dirty, destination_pattern->text().simplified());
+    m_description.insert(m_dirty, taskDescription->toPlainText().simplified());
+    QString enabledTypes;
+    if (enable_video->isChecked()) {
+        enabledTypes.append(QLatin1String("v"));
+    }
+    if (enable_audio->isChecked()) {
+        enabledTypes.append(QLatin1String("a"));
+    }
+    if (enable_image->isChecked()) {
+        enabledTypes.append(QLatin1String("i"));
+    }
+    m_enableType.insert(m_dirty, enabledTypes);
+    m_param1Type.insert(m_dirty, param1_islist->isChecked() ? QLatin1String("list") : QLatin1String("file"));
+    m_param2Type.insert(m_dirty, param2_islist->isChecked() ? QLatin1String("list") : QLatin1String("file"));
+    QStringList option1 = param1_list->toPlainText().split(QLatin1Char('\n'));
+    m_param1List.insert(m_dirty, option1.join(QLatin1String("  ")));
+    QStringList option2 = param2_list->toPlainText().split(QLatin1Char('\n'));
+    m_param2List.insert(m_dirty, option2.join(QLatin1String("  ")));
+    m_param1Name.insert(m_dirty, param1_name->text());
+    m_param2Name.insert(m_dirty, param2_name->text());
+    m_description.insert(m_dirty, taskDescription->toPlainText());
     m_dirty.clear();
 }
 
@@ -244,6 +365,14 @@ void ClipJobManager::writePresetsToConfig()
     writeGroup(conf, QStringLiteral("Output"), m_output);
     writeGroup(conf, QStringLiteral("FolderName"), m_folderNames);
     writeGroup(conf, QStringLiteral("FolderUse"), m_folderUse);
+    writeGroup(conf, QStringLiteral("EnabledTypes"), m_enableType);
+    writeGroup(conf, QStringLiteral("Param1Type"), m_param1Type);
+    writeGroup(conf, QStringLiteral("Param2Type"), m_param2Type);
+    writeGroup(conf, QStringLiteral("Param1List"), m_param1List);
+    writeGroup(conf, QStringLiteral("Param2List"), m_param2List);
+    writeGroup(conf, QStringLiteral("Param1Name"), m_param1Name);
+    writeGroup(conf, QStringLiteral("Param2Name"), m_param2Name);
+    writeGroup(conf, QStringLiteral("Description"), m_description);
 }
 
 void ClipJobManager::addJob()
@@ -270,6 +399,7 @@ void ClipJobManager::addJob()
     QListWidgetItem *item = new QListWidgetItem(jobName, job_list, QListWidgetItem::UserType);
     item->setData(Qt::UserRole, uuid);
     m_folderUse.insert(uuid, QStringLiteral("replace"));
+    m_enableType.insert(uuid, QStringLiteral("v"));
     item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsEnabled);
     job_list->setCurrentItem(item);
     KConfig conf(QStringLiteral("clipjobsettings.rc"), KConfig::CascadeConfig, QStandardPaths::AppDataLocation);
@@ -298,6 +428,14 @@ void ClipJobManager::deleteJob()
             m_output.remove(jobId);
             m_folderNames.remove(jobId);
             m_folderUse.remove(jobId);
+            m_enableType.remove(jobId);
+            m_param1Type.remove(jobId);
+            m_param1List.remove(jobId);
+            m_param2Type.remove(jobId);
+            m_param2List.remove(jobId);
+            m_param1Name.remove(jobId);
+            m_param2Name.remove(jobId);
+            m_description.remove(jobId);
             m_dirty.clear();
             job_list->setCurrentRow(0);
         }
@@ -306,7 +444,6 @@ void ClipJobManager::deleteJob()
 
 void ClipJobManager::updateName(QListWidgetItem *item)
 {
-    KConfig conf(QStringLiteral("clipjobsettings.rc"), KConfig::CascadeConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup idGroup(&conf, "Ids");
-    idGroup.writeEntry(item->data(Qt::UserRole).toString(), item->text());
+    setDirty();
+    m_ids.insert(m_dirty, item->text());
 }
