@@ -16,6 +16,7 @@
 
 #include <QEvent>
 #include <QKeyEvent>
+#include <QMenu>
 #include <QToolButton>
 
 ShiftEnterFilter::ShiftEnterFilter(QObject *parent)
@@ -52,11 +53,13 @@ SubtitleEdit::SubtitleEdit(QWidget *parent)
         if (m_activeSub > -1) {
             buttonApply->setEnabled(true);
         }
+        updateCharInfo();
     });
     connect(subText, &KTextEdit::cursorPositionChanged, this, [this]() {
         if (m_activeSub > -1) {
             buttonCut->setEnabled(true);
         }
+        updateCharInfo();
     });
 
     connect(buttonStyle, &QToolButton::toggled, this, [this](bool toggle) { stackedWidget->setCurrentIndex(toggle ? 1 : 0); });
@@ -144,6 +147,51 @@ SubtitleEdit::SubtitleEdit(QWidget *parent)
     alignment->addItem(i18n("Top Center"), 6);
     alignment->addItem(i18n("Top Right"), 7);
     connect(alignment, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &SubtitleEdit::updateStyle);
+    QAction *zoomIn = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18n("Zoom In"), this);
+    connect(zoomIn, &QAction::triggered, this, &SubtitleEdit::slotZoomIn);
+    QAction *zoomOut = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom Out"), this);
+    connect(zoomOut, &QAction::triggered, this, &SubtitleEdit::slotZoomOut);
+    QMenu *menu = new QMenu(this);
+    menu->addAction(zoomIn);
+    menu->addAction(zoomOut);
+    subMenu->setMenu(menu);
+    if (KdenliveSettings::subtitleEditFontSize() > 0) {
+        QTextCursor cursor = subText->textCursor();
+        subText->selectAll();
+        subText->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+        subText->setTextCursor(cursor);
+    }
+}
+
+void SubtitleEdit::slotZoomIn()
+{
+    QTextCursor cursor = subText->textCursor();
+    subText->selectAll();
+    qreal fontSize = QFontInfo(subText->currentFont()).pointSizeF() * 1.2;
+    KdenliveSettings::setSubtitleEditFontSize(fontSize);
+    subText->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+    subText->setTextCursor(cursor);
+}
+
+void SubtitleEdit::slotZoomOut()
+{
+    QTextCursor cursor = subText->textCursor();
+    subText->selectAll();
+    qreal fontSize = QFontInfo(subText->currentFont()).pointSizeF() / 1.2;
+    fontSize = qMax(fontSize, QFontInfo(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont)).pointSizeF());
+    KdenliveSettings::setSubtitleEditFontSize(fontSize);
+    subText->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+    subText->setTextCursor(cursor);
+}
+
+void SubtitleEdit::applyFontSize()
+{
+    if (KdenliveSettings::subtitleEditFontSize() > 0) {
+        QTextCursor cursor = subText->textCursor();
+        subText->selectAll();
+        subText->setFontPointSize(KdenliveSettings::subtitleEditFontSize());
+        subText->setTextCursor(cursor);
+    }
 }
 
 void SubtitleEdit::updateStyle()
@@ -355,6 +403,8 @@ void SubtitleEdit::setActiveSubtitle(int id)
         QSignalBlocker bk(subText);
         subText->clear();
     }
+    updateCharInfo();
+    applyFontSize();
 }
 
 void SubtitleEdit::goToPrevious()
@@ -387,6 +437,7 @@ void SubtitleEdit::goToPrevious()
             pCore->selectTimelineItem(id);
         }
     }
+    updateCharInfo();
 }
 
 void SubtitleEdit::goToNext()
@@ -419,4 +470,10 @@ void SubtitleEdit::goToNext()
             pCore->selectTimelineItem(id);
         }
     }
+    updateCharInfo();
+}
+
+void SubtitleEdit::updateCharInfo()
+{
+    char_count->setText(i18n("Character: %1, total: <b>%2</b>", subText->textCursor().position(), subText->document()->characterCount()));
 }
