@@ -26,6 +26,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "mltcontroller/clipcontroller.h"
 #include "profiles/profilemodel.hpp"
 #include "profiles/profilerepository.hpp"
+#include "timeline2/model/builders/meltBuilder.hpp"
 #include "timeline2/model/timelineitemmodel.hpp"
 #include "titler/titlewidget.h"
 #include "transitions/transitionsrepository.hpp"
@@ -1011,6 +1012,11 @@ bool KdenliveDoc::sequenceThumbRequiresRefresh(const QUuid &uuid) const
     return m_sequenceThumbsNeedsRefresh.contains(uuid);
 }
 
+void KdenliveDoc::setSequenceThumbRequiresUpdate(const QUuid &uuid)
+{
+    m_sequenceThumbsNeedsRefresh.insert(uuid);
+}
+
 void KdenliveDoc::sequenceThumbUpdated(const QUuid &uuid)
 {
     m_sequenceThumbsNeedsRefresh.remove(uuid);
@@ -2079,12 +2085,15 @@ QStringList KdenliveDoc::getProxyHashList()
     return pCore->bin()->getProxyHashList();
 }
 
-std::shared_ptr<TimelineItemModel> KdenliveDoc::getTimeline(const QUuid &uuid)
+std::shared_ptr<TimelineItemModel> KdenliveDoc::getTimeline(const QUuid &uuid, bool allowEmpty)
 {
     if (m_timelines.contains(uuid)) {
         return m_timelines.value(uuid);
     }
-    qDebug() << "REQUESTING UNKNOWN TIMELINE: " << uuid;
+    if (!allowEmpty) {
+        qDebug() << "REQUESTING UNKNOWN TIMELINE: " << uuid;
+        Q_ASSERT(false);
+    }
     return nullptr;
 }
 
@@ -2093,14 +2102,29 @@ QList<QUuid> KdenliveDoc::getTimelinesUuids() const
     return m_timelines.keys();
 }
 
+QStringList KdenliveDoc::getTimelinesIds()
+{
+    QStringList ids;
+    QMapIterator<QUuid, std::shared_ptr<TimelineItemModel>> j(m_timelines);
+    while (j.hasNext()) {
+        j.next();
+        ids << QString(j.value()->tractor()->get("id"));
+    }
+    return ids;
+}
+
 void KdenliveDoc::addTimeline(const QUuid &uuid, std::shared_ptr<TimelineItemModel> model, bool force)
 {
     if (force && m_timelines.find(uuid) != m_timelines.end()) {
-        std::shared_ptr<TimelineItemModel> model = m_timelines.take(uuid);
-        model.reset();
+        std::shared_ptr<TimelineItemModel> previousModel = m_timelines.take(uuid);
+        previousModel.reset();
     }
     if (m_timelines.find(uuid) != m_timelines.end()) {
         qDebug() << "::::: TIMELINE " << uuid << " already inserted in project";
+        if (m_timelines.value(uuid) != model) {
+            qDebug() << "::::: TIMELINE INCONSISTENCY";
+            Q_ASSERT(false);
+        }
         return;
     }
     if (m_timelines.isEmpty()) {
@@ -2142,17 +2166,22 @@ void KdenliveDoc::loadSequenceGroupsAndGuides(const QUuid &uuid)
     connect(model.get(), &TimelineModel::saveGuideCategories, this, &KdenliveDoc::saveGuideCategories);
 }
 
-void KdenliveDoc::closeTimeline(const QUuid uuid)
+void KdenliveDoc::closeTimeline(const QUuid uuid, bool onDeletion)
 {
     Q_ASSERT(m_timelines.find(uuid) != m_timelines.end());
     // Sync all sequence properties
-    std::shared_ptr<TimelineItemModel> model = m_timelines.take(uuid);
-    if (!closing) {
-        setSequenceProperty(uuid, QStringLiteral("groups"), model->groupsData());
-        model->passSequenceProperties(getSequenceProperties(uuid));
+    if (onDeletion) {
+        auto model = m_timelines.take(uuid);
+        model->prepareClose(!closing);
+        model.reset();
+    } else {
+        auto model = m_timelines.value(uuid);
+        if (!closing) {
+            setSequenceProperty(uuid, QStringLiteral("groups"), model->groupsData());
+            model->passSequenceProperties(getSequenceProperties(uuid));
+        }
+        model->isClosed = true;
     }
-    model->prepareClose(!closing);
-    model.reset();
     // Clear all sequence properties
     m_sequenceProperties.remove(uuid);
 }
