@@ -276,13 +276,16 @@ public:
     /** @brief Load the guides into the model for a sequence.*/
     void loadSequenceGroupsAndGuides(const QUuid &uuid);
     /** @brief Get a timeline by its uuid.*/
-    std::shared_ptr<TimelineItemModel> getTimeline(const QUuid &uuid);
+    std::shared_ptr<TimelineItemModel> getTimeline(const QUuid &uuid, bool allowEmpty = false);
     /** @brief Before closing a timeline, store its groups and other properties.*/
-    void closeTimeline(const QUuid uuid);
+    void closeTimeline(const QUuid uuid, bool onDeletion = true);
     /** @brief store groups in our properties.*/
     void storeGroups(const QUuid &uuid);
     void checkUsage(const QUuid &uuid);
+    /** @brief Return all timelines UUIDs.*/
     QList<QUuid> getTimelinesUuids() const;
+    /** @brief Return all timelines MLT ids.*/
+    QStringList getTimelinesIds();
     /** @brief Returns the number of timelines in this project.*/
     int openedTimelineCount() const;
     /** @brief Get the currently active project name.*/
@@ -291,6 +294,7 @@ public:
     const QUuid uuid() const;
     /** @brief Returns true if a sequence thumbnail needs an update.*/
     bool sequenceThumbRequiresRefresh(const QUuid &uuid) const;
+    void setSequenceThumbRequiresUpdate(const QUuid &uuid);
     /** @brief Thumbnail for a sequence was updated, remove it from the update list.*/
     void sequenceThumbUpdated(const QUuid &uuid);
 
