@@ -139,6 +139,9 @@ public:
     /** @brief Returns a list of zones for all effects */
     QVariantList getEffectZones() const;
 
+    /** @brief Copy all Kdenlive effects of this track on a producer */
+    void passEffects(Mlt::Producer *producer, const QString &exception = QString());
+
 public Q_SLOTS:
     /** @brief Delete an effect from the stack */
     void removeEffect(const std::shared_ptr<EffectItemModel> &effect);
