@@ -48,12 +48,12 @@ void FilterTask::start(const ObjectId &owner, const QString &binId, const std::w
     FilterTask *task = new FilterTask(owner, binId, model, assetId, in, out, filterName, filterParams, filterData, consumerArgs, object);
     // Otherwise, start a filter thread.
     task->m_isForce = force;
-    pCore->taskManager.startTask(owner.second, task);
+    pCore->taskManager.startTask(owner.itemId, task);
 }
 
 void FilterTask::run()
 {
-    AbstractTaskDone whenFinished(m_owner.second, this);
+    AbstractTaskDone whenFinished(m_owner.itemId, this);
     if (m_isCanceled || pCore->taskManager.isBlocked()) {
         return;
     }
@@ -118,10 +118,10 @@ void FilterTask::run()
                     producer->attach(*filter);
                 }
             }
-            if (m_owner.first == ObjectType::TimelineClip) {
+            if (m_owner.type == ObjectType::TimelineClip) {
                 // Add the timeline clip effects
-                std::shared_ptr<EffectStackModel> stack = pCore->getItemEffectStack(pCore->currentTimelineId(), int(m_owner.first), m_owner.second);
-                stack->passEffects(producer.get());
+                std::shared_ptr<EffectStackModel> stack = pCore->getItemEffectStack(pCore->currentTimelineId(), int(m_owner.type), m_owner.itemId);
+                stack->passEffects(producer.get(), m_filterName);
             }
         }
         if ((producer == nullptr) || !producer->is_valid()) {
@@ -138,10 +138,10 @@ void FilterTask::run()
     } else {
         // Filter applied on a track of master producer, leave config to source job
         // We are on master or track, configure producer accordingly
-        if (m_owner.first == ObjectType::Master) {
+        if (m_owner.type == ObjectType::Master) {
             producer = pCore->getMasterProducerInstance();
-        } else if (m_owner.first == ObjectType::TimelineTrack) {
-            producer = pCore->getTrackProducerInstance(m_owner.second);
+        } else if (m_owner.type == ObjectType::TimelineTrack) {
+            producer = pCore->getTrackProducerInstance(m_owner.itemId);
         }
     }
 
@@ -255,7 +255,7 @@ void FilterTask::run()
     m_jobProcess.reset(new QProcess);
     QObject::connect(this, &AbstractTask::jobCanceled, m_jobProcess.get(), &QProcess::kill, Qt::DirectConnection);
     QObject::connect(m_jobProcess.get(), &QProcess::readyReadStandardError, this, &FilterTask::processLogInfo);
-    m_jobProcess->start(KdenliveSettings::rendererpath(), args);
+    m_jobProcess->start(KdenliveSettings::meltpath(), args);
     m_jobProcess->waitForFinished(-1);
     bool result = m_jobProcess->exitStatus() == QProcess::NormalExit;
     m_progress = 100;
@@ -282,8 +282,12 @@ void FilterTask::run()
         QDomNodeList filters = dom.elementsByTagName(QLatin1String("filter"));
         for (int i = 0; i < filters.count(); ++i) {
             QDomElement currentParameter = filters.item(i).toElement();
-            if (Xml::getXmlProperty(currentParameter, QLatin1String("kdenlive:id")) == QLatin1String("kdenlive-analysis")) {
+            if (Xml::getXmlProperty(currentParameter, QLatin1String("mlt_service")) == m_filterName) {
                 resultData = Xml::getXmlProperty(currentParameter, key);
+            } else if (Xml::getXmlProperty(currentParameter, QLatin1String("kdenlive:id")) == QLatin1String("kdenlive-analysis")) {
+                resultData = Xml::getXmlProperty(currentParameter, key);
+            }
+            if (!resultData.isEmpty()) {
                 break;
             }
         }
