@@ -6,6 +6,7 @@
 */
 
 #include "scopewidget.h"
+#include "core.h"
 #include "kdenlive_debug.h"
 #include <QtConcurrent>
 
@@ -31,7 +32,11 @@ void ScopeWidget::onNewFrame(const SharedFrame &frame)
 void ScopeWidget::requestRefresh()
 {
     if (m_future.isFinished()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         m_future = QtConcurrent::run(this, &ScopeWidget::refreshInThread);
+#else
+        m_future = QtConcurrent::run(&ScopeWidget::refreshInThread, this);
+#endif
     } else {
         m_refreshPending = true;
     }
@@ -39,7 +44,7 @@ void ScopeWidget::requestRefresh()
 
 void ScopeWidget::refreshInThread()
 {
-    if (m_size.isEmpty()) {
+    if (m_size.isEmpty() && !pCore->audioMixerVisible) {
         return;
     }
 
