@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef PROVIDERSREPOSITORY_H
-#define PROVIDERSREPOSITORY_H
+#pragma once
 
 #include "definitions.h"
 #include "providermodel.hpp"
@@ -25,12 +24,11 @@ public:
     static std::unique_ptr<ProvidersRepository> &get();
 
     /** @brief Reloads all the providers from the disk */
-    void refresh(bool fullRefresh = true); //TODO: change to false
+    void refresh(bool fullRefresh = true); // TODO: change to false
 
-    QVector<QPair<QString,QString>> getAllProviers() const;
+    QVector<QPair<QString, QString>> getAllProviers() const;
     std::unique_ptr<ProviderModel> &getProvider(const QString &path);
 
-
 protected:
     ProvidersRepository();
 
@@ -41,7 +39,4 @@ protected:
     mutable QReadWriteLock m_mutex;
 
     std::unordered_map<QString, std::unique_ptr<ProviderModel>> m_providers;
-
 };
-
-#endif // PROVIDERSREPOSITORY_H
