@@ -263,6 +263,10 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
         }
     }
     activateDocument(m_project->activeUuid);
+    std::shared_ptr<ProjectClip> mainClip = pCore->projectItemModel()->getSequenceClip(m_project->uuid());
+    if (mainClip) {
+        mainClip->reloadTimeline(m_activeTimelineModel->getMasterEffectStackModel());
+    }
     Q_EMIT docOpened(m_project);
     m_project->loading = false;
     m_lastSave.start();
@@ -325,10 +329,40 @@ void ProjectManager::testSetActiveDocument(KdenliveDoc *doc, std::shared_ptr<Tim
             qDebug() << "===== LOADING PROJECT INTERNAL ERROR";
         }
     }
-    m_project->addTimeline(doc->uuid(), timeline);
+    const QUuid uuid = timeline->uuid();
+    m_project->addTimeline(uuid, timeline);
+    timeline->isClosed = false;
     m_activeTimelineModel = timeline;
-    m_project->activeUuid = doc->uuid();
-    m_project->loadSequenceGroupsAndGuides(doc->uuid());
+    m_project->activeUuid = uuid;
+    m_project->loadSequenceGroupsAndGuides(uuid);
+    // Open all other timelines
+    QMap<QUuid, QString> allSequences = pCore->projectItemModel()->getAllSequenceClips();
+    QMapIterator<QUuid, QString> i(allSequences);
+    while (i.hasNext()) {
+        i.next();
+        if (m_project->getTimeline(i.key(), true) == nullptr) {
+            const QUuid uid = i.key();
+            std::shared_ptr<Mlt::Tractor> tc = pCore->projectItemModel()->getExtraTimeline(uid.toString());
+            if (tc) {
+                std::shared_ptr<TimelineItemModel> timelineModel = TimelineItemModel::construct(uid, m_project->commandStack());
+                const QString chunks = m_project->getSequenceProperty(uid, QStringLiteral("previewchunks"));
+                const QString dirty = m_project->getSequenceProperty(uid, QStringLiteral("dirtypreviewchunks"));
+                if (constructTimelineFromTractor(timelineModel, nullptr, *tc.get(), nullptr, m_project->modifiedDecimalPoint(), chunks, dirty)) {
+                    m_project->addTimeline(uid, timelineModel, false);
+                    pCore->projectItemModel()->setExtraTimelineSaved(uid.toString());
+                    std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor());
+                    passSequenceProperties(uid, prod, *tc.get(), timelineModel, nullptr);
+                    std::shared_ptr<ProjectClip> clip = pCore->projectItemModel()->getClipByBinID(i.value());
+                    prod->parent().set("kdenlive:clipname", clip->clipName().toUtf8().constData());
+                    prod->set("kdenlive:description", clip->description().toUtf8().constData());
+                    // Store sequence properties for later re-use
+                    m_project->loadSequenceGroupsAndGuides(uid);
+                    clip->setProducer(prod, false, false);
+                    clip->reloadTimeline(timelineModel->getMasterEffectStackModel());
+                }
+            }
+        }
+    }
 }
 
 std::shared_ptr<TimelineItemModel> ProjectManager::getTimeline()
@@ -408,13 +442,13 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
             for (auto &uid : uuids) {
                 pCore->window()->closeTimelineTab(uid);
                 pCore->window()->resetSubtitles(uid);
-                m_project->closeTimeline(uid);
+                m_project->closeTimeline(uid, true);
             }
         } else {
             // Close all timelines
             const QList<QUuid> uuids = m_project->getTimelinesUuids();
             for (auto &uid : uuids) {
-                m_project->closeTimeline(uid);
+                m_project->closeTimeline(uid, true);
             }
         }
     }
@@ -451,6 +485,7 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveOverExis
     prepareSave();
     QString saveFolder = QFileInfo(outputFileName).absolutePath();
     m_project->updateWorkFilesBeforeSave(outputFileName);
+    checkProjectIntegrity();
     QString scene = projectSceneList(saveFolder);
     if (!m_replacementPattern.isEmpty()) {
         QMapIterator<QString, QString> i(m_replacementPattern);
@@ -827,15 +862,46 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBa
 
     // Re-open active timelines
     QStringList openedTimelines = m_project->getDocumentProperty(QStringLiteral("opensequences")).split(QLatin1Char(';'), Qt::SkipEmptyParts);
+    QList<QUuid> openedUuids;
     for (auto &uid : openedTimelines) {
         const QUuid uuid(uid);
+        openedUuids << uuid;
         const QString binId = pCore->projectItemModel()->getSequenceId(uuid);
         if (!binId.isEmpty()) {
             openTimeline(binId, uuid);
         }
     }
     // Now that sequence clips are fully built, fetch thumbnails
-    const QStringList sequenceIds = pCore->projectItemModel()->getAllSequenceClips().values();
+    auto sequences = pCore->projectItemModel()->getAllSequenceClips();
+    QList<QUuid> uuids = sequences.keys();
+    // Load all sequence models into memory
+    for (auto &uid : uuids) {
+        if (pCore->currentDoc()->getTimeline(uid, true) == nullptr) {
+            std::shared_ptr<Mlt::Tractor> tc = pCore->projectItemModel()->getExtraTimeline(uid.toString());
+            if (tc) {
+                std::shared_ptr<TimelineItemModel> timelineModel = TimelineItemModel::construct(uid, m_project->commandStack());
+                const QString chunks = m_project->getSequenceProperty(uid, QStringLiteral("previewchunks"));
+                const QString dirty = m_project->getSequenceProperty(uid, QStringLiteral("dirtypreviewchunks"));
+                const QString binId = pCore->projectItemModel()->getSequenceId(uid);
+                m_project->addTimeline(uid, timelineModel, false);
+                if (constructTimelineFromTractor(timelineModel, nullptr, *tc.get(), nullptr, m_project->modifiedDecimalPoint(), chunks, dirty)) {
+                    pCore->projectItemModel()->setExtraTimelineSaved(uid.toString());
+                    std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor());
+                    passSequenceProperties(uid, prod, *tc.get(), timelineModel, nullptr);
+                    std::shared_ptr<ProjectClip> clip = pCore->projectItemModel()->getClipByBinID(binId);
+                    prod->parent().set("kdenlive:clipname", clip->clipName().toUtf8().constData());
+                    prod->set("kdenlive:description", clip->description().toUtf8().constData());
+                    m_project->loadSequenceGroupsAndGuides(uid);
+                    clip->setProducer(prod, false, false);
+                    clip->reloadTimeline(timelineModel->getMasterEffectStackModel());
+                } else {
+                    qWarning() << "XXXXXXXXX\nLOADING TIMELINE " << uid.toString() << " FAILED\n";
+                    m_project->closeTimeline(uid, true);
+                }
+            }
+        }
+    }
+    const QStringList sequenceIds = sequences.values();
     for (auto &id : sequenceIds) {
         ClipLoadTask::start(ObjectId(ObjectType::BinClip, id.toInt(), QUuid()), QDomElement(), true, -1, -1, this);
     }
@@ -882,6 +948,8 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBa
         const QUuid uuid = m_project->activeUuid;
         pCore->monitorManager()->projectMonitor()->adjustRulerSize(m_activeTimelineModel->duration() - 1, m_project->getFilteredGuideModel(uuid));
     }
+
+    checkProjectWarnings();
     delete m_progressDialog;
     m_progressDialog = nullptr;
 }
@@ -961,6 +1029,10 @@ void ProjectManager::slotStartAutoSave()
 
 void ProjectManager::slotAutoSave()
 {
+    if (m_project->loading) {
+        // Dont start autosave if the project is still loading
+        return;
+    }
     prepareSave();
     QString saveFolder = m_project->url().adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
     QString scene = projectSceneList(saveFolder);
@@ -1245,10 +1317,14 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
     Mlt::Tractor tractor(s);
     if (xmlProd->property_exists("kdenlive:projectTractor")) {
         // This is the new multi-timeline document format
+        // Get active sequence uuid
+        std::shared_ptr<Mlt::Producer> tk(tractor.track(0));
+        const QUuid activeUuid(tk->parent().get("kdenlive:uuid"));
+        Q_ASSERT(!activeUuid.isNull());
         m_project->cleanupTimelinePreview(documentDate);
         pCore->projectItemModel()->buildPlaylist(uuid);
         // Load bin playlist
-        return loadProjectBin(tractor, m_progressDialog);
+        return loadProjectBin(tractor, activeUuid, m_progressDialog);
     }
     if (tractor.count() == 0) {
         // Wow we have a project file with empty tractor, probably corrupted, propose to open a recovery file
@@ -1268,6 +1344,7 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
         qDebug() << ":::: NOT FOUND DOCUMENT GUIDES !!!!!!!!!!!\n!!!!!!!!!!!!!!!!!!!!!";
     }
     m_project->addTimeline(uuid, timelineModel);
+    timelineModel->isClosed = false;
     TimelineWidget *documentTimeline = nullptr;
 
     m_project->cleanupTimelinePreview(documentDate);
@@ -1304,8 +1381,26 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
         pCore->projectItemModel()->requestAddFolder(folderId, i18n("Sequences"), QStringLiteral("-1"), undo, redo);
     }
     QString mainId;
-    QPair<int, int> tracks = timelineModel->getAVtracksCount();
     std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(timelineModel->tractor()->cut());
+    passSequenceProperties(uuid, prod, tractor, timelineModel, documentTimeline);
+    pCore->projectItemModel()->requestAddBinClip(mainId, prod, folderId, undo, redo);
+    pCore->projectItemModel()->setSequencesFolder(folderId.toInt());
+    if (pCore->window()) {
+        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration, Qt::UniqueConnection);
+    }
+    std::shared_ptr<ProjectClip> mainClip = pCore->projectItemModel()->getClipByBinID(mainId);
+    m_project->loadSequenceGroupsAndGuides(uuid);
+    timelineModel->setUndoStack(m_project->commandStack());
+
+    // Reset locale to C to ensure numbers are serialised correctly
+    LocaleHandling::resetLocale();
+    return true;
+}
+
+void ProjectManager::passSequenceProperties(const QUuid &uuid, std::shared_ptr<Mlt::Producer> prod, Mlt::Tractor tractor,
+                                            std::shared_ptr<TimelineItemModel> timelineModel, TimelineWidget *timelineWidget)
+{
+    QPair<int, int> tracks = timelineModel->getAVtracksCount();
     prod->parent().set("id", uuid.toString().toUtf8().constData());
     prod->set("kdenlive:uuid", uuid.toString().toUtf8().constData());
     prod->set("kdenlive:clipname", i18n("Sequence 1").toUtf8().constData());
@@ -1329,30 +1424,18 @@ bool ProjectManager::updateTimeline(bool createNewTab, const QString &chunks, co
     } else {
         // Fetch duration from actual tractor
         int projectDuration = timelineModel->duration();
-        if (pCore->window()) {
-            documentTimeline->controller()->checkDuration();
+        if (timelineWidget) {
+            timelineWidget->controller()->checkDuration();
         }
         prod->parent().set("kdenlive:duration", timelineModel->tractor()->frames_to_time(projectDuration + 1));
         prod->parent().set("kdenlive:maxduration", projectDuration + 1);
         prod->parent().set("length", projectDuration + 1);
         prod->parent().set("out", projectDuration);
     }
-    prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
-    // QString retain = QStringLiteral("xml_retain %1").arg(uuid.toString());
-    // pCore->projectItemModel()->projectTractor()->set(retain.toUtf8().constData(), timelineModel->tractor()->get_service(), 0);
-    pCore->projectItemModel()->requestAddBinClip(mainId, prod, folderId, undo, redo);
-    pCore->projectItemModel()->setSequencesFolder(folderId.toInt());
-    if (pCore->window()) {
-        pCore->bin()->registerSequence(uuid, mainId);
-        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration);
+    if (tractor.property_exists("kdenlive:sequenceproperties.timelineHash")) {
+        prod->parent().set("kdenlive:sequenceproperties.timelineHash", tractor.get("kdenlive:sequenceproperties.timelineHash"));
     }
-
-    m_project->loadSequenceGroupsAndGuides(uuid);
-    timelineModel->setUndoStack(m_project->commandStack());
-
-    // Reset locale to C to ensure numbers are serialised correctly
-    LocaleHandling::resetLocale();
-    return true;
+    prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
 }
 
 void ProjectManager::updateSequenceDuration(const QUuid &uuid)
@@ -1625,6 +1708,9 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
     if (pCore->window() && pCore->window()->raiseTimeline(uuid)) {
         return false;
     }
+    if (!duplicate && existingModel == nullptr) {
+        existingModel = m_project->getTimeline(uuid, true);
+    }
 
     // Disable autosave while creating timelines
     m_autoSaveTimer.stop();
@@ -1649,11 +1735,9 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
     }
 
     // Build timeline
-    if (existingModel) {
-        existingModel->m_closing = false;
-    }
     std::shared_ptr<TimelineItemModel> timelineModel = existingModel != nullptr ? existingModel : TimelineItemModel::construct(uuid, m_project->commandStack());
     m_project->addTimeline(uuid, timelineModel);
+    timelineModel->isClosed = false;
     TimelineWidget *timeline = nullptr;
     if (internalLoad) {
         qDebug() << "QQQQQQQQQQQQQQQQQQQQ\nINTERNAL SEQUENCE LOAD\n\nQQQQQQQQQQQQQQQQQQQQQQ";
@@ -1690,14 +1774,11 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
         prod->parent().set("kdenlive:description", clip->description().toUtf8().constData());
         prod->parent().set("kdenlive:uuid", uuid.toString().toUtf8().constData());
         prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
-        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration);
+        QObject::connect(timelineModel.get(), &TimelineModel::durationUpdated, this, &ProjectManager::updateSequenceDuration, Qt::UniqueConnection);
         m_project->loadSequenceGroupsAndGuides(uuid);
         clip->setProducer(prod, false, false);
         if (!duplicate) {
-            clip->reloadTimeline();
-        }
-        if (pCore->bin()) {
-            pCore->bin()->registerSequence(uuid, id);
+            clip->reloadTimeline(timelineModel->getMasterEffectStackModel());
         }
     } else {
         qDebug() << "GOT XML SERV: " << xmlProd->type() << " = " << xmlProd->parent().type();
@@ -1755,7 +1836,6 @@ bool ProjectManager::openTimeline(const QString &id, const QUuid &uuid, int posi
         prod->parent().set("kdenlive:uuid", uuid.toString().toUtf8().constData());
         prod->parent().set("kdenlive:producer_type", ClipType::Timeline);
         if (pCore->bin()) {
-            pCore->bin()->registerSequence(uuid, id);
             pCore->bin()->updateSequenceClip(uuid, timelineModel->duration(), -1);
         }
         updateSequenceProducer(uuid, prod);
@@ -1812,6 +1892,11 @@ int ProjectManager::getTimelinesCount() const
 void ProjectManager::syncTimeline(const QUuid &uuid, bool refresh)
 {
     std::shared_ptr<TimelineItemModel> model = m_project->getTimeline(uuid);
+    doSyncTimeline(model, refresh);
+}
+
+void ProjectManager::doSyncTimeline(std::shared_ptr<TimelineItemModel> model, bool refresh)
+{
     if (model) {
         std::shared_ptr<Mlt::Producer> prod = std::make_shared<Mlt::Producer>(model->tractor());
         int position = -1;
@@ -1821,6 +1906,7 @@ void ProjectManager::syncTimeline(const QUuid &uuid, bool refresh)
                 pCore->window()->getCurrentTimeline()->controller()->saveSequenceProperties();
             }
         }
+        const QUuid &uuid = model->uuid();
         if (refresh) {
             // Store sequence properties for later re-use
             Mlt::Properties sequenceProps;
@@ -1841,11 +1927,13 @@ bool ProjectManager::closeTimeline(const QUuid &uuid, bool onDeletion, bool clea
         qDebug() << "=== ERROR CANNOT FIND TIMELINE TO CLOSE: " << uuid << "\n\nHHHHHHHHHHHH";
         return false;
     }
-    pCore->projectItemModel()->removeReferencedClips(uuid);
     pCore->projectItemModel()->setExtraTimelineSaved(uuid.toString());
     if (onDeletion) {
         // triggered when deleting bin clip, also close timeline tab
-        pCore->window()->closeTimelineTab(uuid);
+        pCore->projectItemModel()->removeReferencedClips(uuid, true);
+        if (pCore->window()) {
+            pCore->window()->closeTimelineTab(uuid);
+        }
     } else {
         if (!m_project->closing && !onDeletion) {
             if (m_project->isModified()) {
@@ -1853,7 +1941,7 @@ bool ProjectManager::closeTimeline(const QUuid &uuid, bool onDeletion, bool clea
             }
         }
     }
-    m_project->closeTimeline(uuid);
+    m_project->closeTimeline(uuid, onDeletion);
     // The undo stack keeps references to guides model and will crash on undo if not cleared
     if (clearUndo) {
         qDebug() << ":::::::::::::: WARNING CLEARING NUDO STACK\n\n:::::::::::::::::";
@@ -1946,3 +2034,10 @@ void ProjectManager::updateSequenceProducer(const QUuid &uuid, std::shared_ptr<M
     qDebug() << "====== STORING SEQUENCE " << uuid << " WITH TKS: " << trac->count();
     pCore->projectItemModel()->storeSequence(uuid.toString(), trac);
 }
+
+void ProjectManager::checkProjectIntegrity()
+{
+    // Ensure the active timeline sequence is correctly inserted in the main_bin playlist
+    const QString activeSequenceId(m_activeTimelineModel->tractor()->get("id"));
+    pCore->projectItemModel()->checkSequenceIntegrity(activeSequenceId);
+}
