@@ -30,6 +30,7 @@ class QAction;
 class QProgressDialog;
 class QUrl;
 class DocUndoStack;
+class TimelineWidget;
 
 /** @class ProjectManager
     @brief Takes care of interaction with projects.
@@ -124,6 +125,7 @@ public:
     /** @brief Update a timeline sequence before saving or extracting xml
      */
     void syncTimeline(const QUuid &uuid, bool refresh = false);
+    void doSyncTimeline(std::shared_ptr<TimelineItemModel> model, bool refresh);
     void setActiveTimeline(const QUuid &uuid);
 
 public Q_SLOTS:
@@ -249,4 +251,9 @@ private:
     void saveRecentFiles();
     /** @brief Project loading failed, ask user if he wants to open a backup */
     void requestBackup(const QString &errorMessage);
+    /** @brief WHen building a sequence producer, ensure we pass along all properties */
+    void passSequenceProperties(const QUuid &uuid, std::shared_ptr<Mlt::Producer> prod, Mlt::Tractor tractor, std::shared_ptr<TimelineItemModel> timelineModel,
+                                TimelineWidget *timelineWidget);
+    /** @brief Ensure sequences are correctly stored in our project model */
+    void checkProjectIntegrity();
 };
