@@ -145,10 +145,10 @@ void ClipModel::registerClipToBin(std::shared_ptr<Mlt::Producer> service, bool r
     binClip->registerService(m_parent, m_id, std::move(service), registerProducer);
 }
 
-void ClipModel::deregisterClipToBin()
+void ClipModel::deregisterClipToBin(const QUuid &uuid)
 {
     std::shared_ptr<ProjectClip> binClip = pCore->projectItemModel()->getClipByBinID(m_binClipId);
-    binClip->deregisterTimelineClip(m_id, isAudioOnly());
+    binClip->deregisterTimelineClip(m_id, isAudioOnly(), uuid);
 }
 
 ClipModel::~ClipModel() = default;
@@ -284,7 +284,7 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
                 }
                 return true;
             }
-            qDebug() << "============\n+++++++++++++++++\nREVRSE TRACK OP FAILED\n\n++++++++++++++++";
+            qDebug() << "============\n+++++++++++++++++\nREVRSE TRACK OP FAILED FOR: " << m_id << "\n\n++++++++++++++++";
             return false;
         };
         Fun preProcess = [this, roles, oldIn, oldOut, newIn = m_position, newOut = m_position + getOut() - getIn(), right, logUndo]() {
@@ -1519,3 +1519,21 @@ const QString ClipModel::clipThumbPath()
     }
     return QString();
 }
+
+void ClipModel::switchBinReference(const QString newId, const QUuid &uuid)
+{
+    deregisterClipToBin(uuid);
+    m_binClipId = newId;
+    refreshProducerFromBin(-1);
+    registerClipToBin(getProducer(), false);
+    if (auto ptr = m_parent.lock()) {
+        ptr->replugClip(m_id);
+        QVector<int> roles{TimelineModel::ClipThumbRole};
+        QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+        ptr->notifyChange(ix, ix, roles);
+        // invalidate timeline preview
+        if (!ptr->getTrackById_const(m_currentTrackId)->isAudioTrack()) {
+            Q_EMIT ptr->invalidateZone(m_position, m_position + getPlaytime());
+        }
+    }
+}
