@@ -36,14 +36,14 @@ public:
        @param undo_stack is a weak pointer to the undo stack of the project
        @param guideModel ptr to the guide model of the project
      */
-    static std::shared_ptr<TimelineItemModel> construct(const QUuid &uuid, Mlt::Profile *profile, std::weak_ptr<DocUndoStack> undo_stack);
+    static std::shared_ptr<TimelineItemModel> construct(const QUuid &uuid, std::weak_ptr<DocUndoStack> undo_stack);
 
     friend bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, Mlt::Tractor tractor);
 
 protected:
     /** @brief this constructor should not be called. Call the static construct instead
      */
-    TimelineItemModel(const QUuid &uuid, Mlt::Profile *profile, std::weak_ptr<DocUndoStack> undo_stack);
+    TimelineItemModel(const QUuid &uuid, std::weak_ptr<DocUndoStack> undo_stack);
 
 public:
     ~TimelineItemModel() override;
