@@ -88,7 +88,7 @@ Q_SIGNALS:
     /** @brief Requests that a given mix is displayed in the asset panel */
     void showMixModel(int cid, std::shared_ptr<AssetParameterModel>, bool refreshOnly);
     /** @brief Requests that a given effectstack model is displayed in the asset panel */
-    void showItemEffectStack(const QString &clipName, std::shared_ptr<EffectStackModel>, QSize, bool);
+    void showItemEffectStack(const QString &clipName, std::shared_ptr<EffectStackModel>, QSize size, bool showKeyframes);
     void showSubtitle(int itemId);
     void updateAssetPosition(int itemId, const QUuid uuid);
     /** @brief Zoom level changed in timeline, update slider
