@@ -66,4 +66,8 @@ void TransitionListWidget::refreshLumas()
 
 void TransitionListWidget::reloadCustomEffectIx(const QModelIndex &) {}
 
+void TransitionListWidget::reloadCustomEffect(const QString &) {}
+
+void TransitionListWidget::reloadTemplates() {}
+
 void TransitionListWidget::editCustomAsset(const QModelIndex &) {}
