@@ -57,7 +57,7 @@ protected:
     /** @brief Returns the path to the effects' preferred list*/
     QString assetPreferredListPath() const override;
 
-    void parseType(QScopedPointer<Mlt::Properties> &metadata, Info &res) override;
+    void parseType(Mlt::Properties *metadata, Info &res) override;
 
     /** @brief Returns the metadata associated with the given asset*/
     Mlt::Properties *getMetadata(const QString &assetId) const override;
