@@ -17,6 +17,9 @@
 
 #include <KActionMenu>
 #include <KColorSchemeModel>
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 107, 0)
+#include <KColorSchemeMenu>
+#endif
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -43,8 +46,12 @@ ThemeManager::ThemeManager(QObject *parent)
             }
         }
     }
-
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 107, 0)
+    m_menu = KColorSchemeMenu::createMenu(this, this);
+    // TODO: select current action?
+#else
     m_menu = createSchemeSelectionMenu(scheme, this);
+#endif
 
     connect(m_menu->menu(), &QMenu::triggered, this, [this](QAction *action) {
         QModelIndex schemeIndex = indexForScheme(KLocalizedString::removeAcceleratorMarker(action->text()));
