@@ -73,10 +73,9 @@ TEST_CASE("Regression")
     undoStack->redo();
     REQUIRE(timeline->getTrackById(1)->checkConsistency());
     pCore->taskManager.slotCancelJobs();
-    mocked.closeTimeline(timeline->uuid());
+    mockedDoc.closing = true;
     timeline.reset();
     binModel->clean();
-    pCore->m_projectManager = nullptr;
 }
 
 TEST_CASE("Regression2")
@@ -232,10 +231,9 @@ TEST_CASE("Regression2")
     REQUIRE(timeline->getTrackById(6)->checkConsistency());
     undoStack->redo();
     pCore->taskManager.slotCancelJobs();
-    mocked.closeTimeline(timeline->uuid());
+    mockedDoc.closing = true;
     timeline.reset();
     binModel->clean();
-    pCore->m_projectManager = nullptr;
 }
 
 /*
@@ -580,10 +578,9 @@ TEST_CASE("FuzzBug1")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
-        pCore->m_projectManager = nullptr;
     }
 }
 
@@ -676,10 +673,9 @@ TEST_CASE("FuzzBug2")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
-        pCore->m_projectManager = nullptr;
     }
 }
 
@@ -738,10 +734,9 @@ TEST_CASE("FuzzBug3")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
-        pCore->m_projectManager = nullptr;
     }
 }
 
@@ -826,10 +821,9 @@ TEST_CASE("FuzzBug4")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
-        pCore->m_projectManager = nullptr;
     }
 }
 
@@ -1039,7 +1033,7 @@ TEST_CASE("FuzzBug5")
         pCore->taskManager.slotCancelJobs();
         mocked.m_activeTimelineModel.reset();
         undoStack->clear();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         binModel->clean();
         timeline_0.reset();
         timeline_1.reset();
@@ -1071,7 +1065,6 @@ TEST_CASE("FuzzBug6")
         TimelineItemModel::finishConstruct(timeline_0);
         pCore->m_projectManager->testSetActiveDocument(&mockedDoc, timeline_0);
 
-        mocked.m_activeTimelineModel = timeline_0;
         Fake(Method(timMock_0, adjustAssetRange));
         REQUIRE(timeline_0->checkConsistency());
         undoStack->undo();
@@ -1139,8 +1132,7 @@ TEST_CASE("FuzzBug6")
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
-        mocked.closeTimeline(timeline_1->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         timeline_1.reset();
         binModel->clean();
@@ -1229,8 +1221,8 @@ TEST_CASE("FuzzBug7")
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
-        undoStack->undo();
         mocked.m_activeTimelineModel = timeline_0;
+        undoStack->undo();
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
@@ -1240,82 +1232,81 @@ TEST_CASE("FuzzBug7")
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
         {
+            mocked.m_activeTimelineModel = timeline_0;
             int dummy_3;
             bool res = timeline_0->requestClipInsertion("2", 1, 20, dummy_3, true, false, true);
             REQUIRE(res == true);
         }
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
+        mocked.m_activeTimelineModel = timeline_0;
         undoStack->undo();
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
-        undoStack->redo();
         mocked.m_activeTimelineModel = timeline_0;
+        undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
         {
+            mocked.m_activeTimelineModel = timeline_0;
             int dummy_3;
             bool res = timeline_0->requestClipInsertion("2", 1, 40, dummy_3, true, false, true);
             REQUIRE(res == true);
         }
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
+        mocked.m_activeTimelineModel = timeline_0;
         undoStack->undo();
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
-        undoStack->redo();
         mocked.m_activeTimelineModel = timeline_0;
+        undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
         {
+            mocked.m_activeTimelineModel = timeline_0;
             int res = timeline_0->requestClipsGroup({4, 3}, true, GroupType::Selection);
             REQUIRE(res == -1);
         }
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
+        mocked.m_activeTimelineModel = timeline_0;
         undoStack->undo();
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
-        undoStack->redo();
         mocked.m_activeTimelineModel = timeline_0;
+        undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
         {
+            mocked.m_activeTimelineModel = timeline_0;
             int res = timeline_0->requestClipsGroup({5, 3}, true, GroupType::Normal);
             REQUIRE(res == 6);
         }
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
+        mocked.m_activeTimelineModel = timeline_0;
         undoStack->undo();
-        mocked.m_activeTimelineModel = timeline_0;
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
-        undoStack->redo();
         mocked.m_activeTimelineModel = timeline_0;
+        undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         mocked.m_activeTimelineModel = timeline_1;
         REQUIRE(timeline_1->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
-        mocked.closeTimeline(timeline_1->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         timeline_1.reset();
         binModel->clean();
@@ -1390,7 +1381,7 @@ TEST_CASE("FuzzBug8")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
     }
@@ -1455,7 +1446,7 @@ TEST_CASE("FuzzBug9")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
     }
@@ -1514,7 +1505,7 @@ TEST_CASE("FuzzBug10")
         undoStack->redo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
     }
@@ -1618,7 +1609,7 @@ TEST_CASE("FuzzBug11")
         undoStack->undo();
         REQUIRE(timeline_0->checkConsistency());
         pCore->taskManager.slotCancelJobs();
-        mocked.closeTimeline(timeline_0->uuid());
+        mockedDoc.closing = true;
         timeline_0.reset();
         binModel->clean();
     }
